@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2015 CZ.NIC
+ * Copyright (C) 2014-2017 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 #include <QRegExp>
 #include <QSqlDatabase>
 
-#include "message_db_set.h"
+#include "src/io/message_db_set.h"
 #include "src/log/log.h"
 
 MessageDbSet::MessageDbSet(const QString &locDir, const QString &primaryKey,
