@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2016 CZ.NIC
+ * Copyright (C) 2014-2017 CZ.NIC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@ public:
 	 *
 	 * @param[in] parent Parent widget.
 	 */
-	explicit LoweredTableView(QWidget *parent = 0);
+	explicit LoweredTableView(QWidget *parent = Q_NULLPTR);
 
 	/*!
 	 * @brief Sets narrowed row size.
